package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 29, 2026
License: MIT
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command.
type ExportResult struct {
Rank int `json:"rank"`
Score float32 `json:"score"`
Path string `json:"path"`
ChunkID int64 `json:"chunk_id"`
Index int `json:"index"`
Snippet string `json:"snippet"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.